@@ -1,12 +1,14 @@
 use std::env;
-mod controllers;
-mod index;
-mod init;
-mod gen;
-mod core;
+mod tasks;
+use tasks::gen;
+use tasks::help;
+use tasks::index;
+use tasks::init;
+mod assets;
 use brown; //for controllers main.rs does not need it 
 
 fn main() {
+  //init::init();
   println!("                                                  ");
   println!("                                                  ");
   println!("================== HULK ======================= ");
@@ -49,12 +51,12 @@ fn main() {
                         Err(e)=> println!("{:?}",&e),
                       } 
           },
-          "help" => controllers::help(),
+          "help" => help::help(),
           _ => println!("Command not found ==> {}", v),
         }
       
     },
-    None => {controllers::help()},
+    None => {help::help()},
   }
   
   println!("                                                  ");
